emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

emacs-29 70ecdebc92: ; Fix typos (don't abbreviate "with" or "without")


From: Stefan Kangas
Subject: emacs-29 70ecdebc92: ; Fix typos (don't abbreviate "with" or "without")
Date: Thu, 1 Dec 2022 10:36:23 -0500 (EST)

branch: emacs-29
commit 70ecdebc92c879af90f2d25a2b751d1cc4f3f80d
Author: Stefan Kangas <stefankangas@gmail.com>
Commit: Stefan Kangas <stefankangas@gmail.com>

    ; Fix typos (don't abbreviate "with" or "without")
---
 ChangeLog.2                                          |  4 ++--
 ChangeLog.3                                          | 20 +++++++++++---------
 doc/lispref/display.texi                             |  2 +-
 lib-src/ChangeLog.1                                  |  2 +-
 lisp/ChangeLog.10                                    |  2 +-
 lisp/ChangeLog.11                                    |  9 +++++----
 lisp/ChangeLog.12                                    |  7 ++++---
 lisp/ChangeLog.14                                    |  2 +-
 lisp/ChangeLog.16                                    |  3 ++-
 lisp/ChangeLog.3                                     |  3 ++-
 lisp/ChangeLog.4                                     |  3 ++-
 lisp/ChangeLog.6                                     |  2 +-
 lisp/ChangeLog.7                                     |  5 +++--
 lisp/ChangeLog.8                                     | 11 ++++++-----
 lisp/ChangeLog.9                                     |  8 ++++----
 lisp/autorevert.el                                   |  4 ++--
 lisp/comint.el                                       |  2 +-
 lisp/emacs-lisp/chart.el                             |  2 +-
 lisp/emacs-lisp/package.el                           |  2 +-
 lisp/epg.el                                          |  2 +-
 lisp/gnus/ChangeLog.3                                |  3 ++-
 lisp/gnus/gnus-cache.el                              |  2 +-
 lisp/gnus/message.el                                 |  2 +-
 lisp/net/ange-ftp.el                                 |  2 +-
 lisp/net/tramp.el                                    |  4 ++--
 lisp/obsolete/rfc2368.el                             | 12 ++++++------
 lisp/org/ChangeLog.1                                 |  4 ++--
 lisp/play/zone.el                                    |  2 +-
 lisp/progmodes/antlr-mode.el                         |  2 +-
 lisp/progmodes/asm-mode.el                           |  2 +-
 lisp/progmodes/compile.el                            |  2 +-
 lisp/progmodes/scheme.el                             |  2 +-
 lisp/shell.el                                        |  2 +-
 lisp/strokes.el                                      |  2 +-
 lisp/term.el                                         |  2 +-
 lisp/textmodes/reftex.el                             |  3 ++-
 lisp/vc/vc-rcs.el                                    |  4 ++--
 src/ChangeLog.11                                     |  2 +-
 src/ChangeLog.3                                      |  2 +-
 src/xdisp.c                                          |  3 ++-
 test/lisp/cedet/semantic-utest.el                    |  2 +-
 .../eieio-tests/eieio-test-methodinvoke.el           |  2 +-
 test/lisp/erc/erc-join-tests.el                      |  2 +-
 test/lisp/filenotify-tests.el                        |  4 ++--
 test/lisp/net/tramp-archive-tests.el                 |  2 +-
 test/lisp/net/tramp-tests.el                         | 12 ++++++------
 test/manual/cedet/cedet-utests.el                    |  3 ++-
 test/manual/cedet/semantic-tests.el                  |  3 ++-
 test/manual/cedet/tests/testpolymorph.cpp            | 10 +++++-----
 test/manual/cedet/tests/testsppreplace.c             |  4 ++--
 test/manual/cedet/tests/testsppreplaced.c            |  4 ++--
 51 files changed, 108 insertions(+), 94 deletions(-)

diff --git a/ChangeLog.2 b/ChangeLog.2
index 483dec2542..143be59c9e 100644
--- a/ChangeLog.2
+++ b/ChangeLog.2
@@ -23054,8 +23054,8 @@
 
        Fix tests in file-notify-tests.el
        * test/automated/file-notify-tests.el: Remove Tramp declarations.
-       (file-notify-test00-availability): Print remote command w/o Tramp
-       internal functions.
+       (file-notify-test00-availability): Print remote command without
+       Tramp internal functions.
        (file-notify-test02-events, file-notify-test02-events-remote):
        Adapt docstring.
        (file-notify-test03-autorevert): Use `format-message' when
diff --git a/ChangeLog.3 b/ChangeLog.3
index e7ad130d00..136a276b63 100644
--- a/ChangeLog.3
+++ b/ChangeLog.3
@@ -32685,7 +32685,7 @@
        * test/README: Mention $EMACS_TEST_DIRECTORY.
 
        * test/lisp/image-tests.el (image-tests--emacs-images-directory):
-       Use `data-directory', for runs w/o of make.
+       Use `data-directory', for runs without of make.
        (image-type/from-filename): Check for `image-load-path'.
 
 2021-03-16  Michael Albinus  <michael.albinus@gmx.de>
@@ -69072,7 +69072,7 @@
 
 2020-08-27  Tino Calancha  <tino.calancha@gmail.com>
 
-       dired: Show broken/circular links w/ different face
+       dired: Show broken/circular links with different face
 
        * lisp/dired.el (dired-broken-symlink): New face.
        (dired-font-lock-keywords):
@@ -143455,7 +143455,8 @@
 
 2018-12-28  Michael Albinus  <michael.albinus@gmx.de>
 
-       * lisp/net/tramp-sh.el (tramp-set-remote-path): Handle platforms w/o 
getconf.
+       * lisp/net/tramp-sh.el (tramp-set-remote-path): Handle platforms
+       without getconf.
 
 2018-12-27  Paul Eggert  <eggert@cs.ucla.edu>
 
@@ -157203,7 +157204,7 @@
        Fix file name completion in Tramp
 
        * lisp/net/tramp.el (tramp-handle-file-name-directory): Fix case
-       of localname starts w/o a slash.
+       of localname starts without a slash.
 
        * test/lisp/net/tramp-tests.el (tramp-test06-directory-file-name):
        Extend test.
@@ -177123,7 +177124,7 @@
        Mention pcase as a fifth conditional form
 
        * doc/lispref/control.texi (Conditionals): ...here,
-       in first para, w/ xref to "Pattern-Matching Conditional".
+       in first para, with xref to "Pattern-Matching Conditional".
 
 2018-05-27  Thien-Thi Nguyen  <ttn@gnu.org>
 
@@ -192390,7 +192391,7 @@
 
 2017-08-06  Tino Calancha  <tino.calancha@gmail.com>
 
-       Dired w/ eshell-ls: Handle shell wildcards in file name
+       Dired with eshell-ls: Handle shell wildcards in file name
 
        * lisp/eshell/em-ls.el (eshell-ls--insert-directory):
        Use eshell-extended-glob (Bug#27844).
@@ -192767,7 +192768,7 @@
 
 2017-08-01  Tino Calancha  <tino.calancha@gmail.com>
 
-       Insert subdir content if dir-or-list is a string w/o wildcards
+       Insert subdir content if dir-or-list is a string without wildcards
 
        * lisp/eshell/em-ls.el (eshell-ls--insert-directory):
        Append '("-d") into 'eshell-ls-dired-initial-args'
@@ -206236,7 +206237,7 @@
 
 2017-03-03  Rolf Ade  <rolf@pointsman.de>  (tiny change)
 
-       sql-mode w/ sqlite: In-memory database
+       sql-mode with sqlite: In-memory database
 
        Enable the usage of an in-memory database. Prior to this, sql-mode w/
        sqlite could only be used with file databases.
@@ -211195,7 +211196,8 @@
 
 2017-01-03  Stefan Monnier  <monnier@iro.umontreal.ca>
 
-       (cl-defstruct): Improve error message for slots w/o value (bug#25312)
+       (cl-defstruct): Improve error message for slots without value
+       (bug#25312)
 
        * lisp/emacs-lisp/cl-macs.el (cl-defstruct): Don't signal an error but
        emit a warning for those coders who forgot to put a default value in
diff --git a/doc/lispref/display.texi b/doc/lispref/display.texi
index 10a1a18dd1..60955fd319 100644
--- a/doc/lispref/display.texi
+++ b/doc/lispref/display.texi
@@ -5419,7 +5419,7 @@ before @code{height}.
 
 @c We put all the '@code{(when ...)}' on one line to encourage
 @c makeinfo's end-of-sentence heuristics to DTRT.  Previously, the dot
-@c was at eol; the info file ended up w/ two spaces rendered after it.
+@c was at eol; the info file ended up with two spaces rendered after it.
   You can make any display specification conditional.  To do that,
 package it in another list of the form
 @code{(when @var{condition} . @var{spec})}.
diff --git a/lib-src/ChangeLog.1 b/lib-src/ChangeLog.1
index 0829f50a56..c5988072e9 100644
--- a/lib-src/ChangeLog.1
+++ b/lib-src/ChangeLog.1
@@ -3661,7 +3661,7 @@
 2004-05-07  Thien-Thi Nguyen  <ttn@gnu.org>
 
        * b2m.c (GOOD, BAD): Delete macros.  Throughout,
-       replace w/ `EXIT_SUCCESS' and `EXIT_FAILURE', respectively.
+       replace with `EXIT_SUCCESS' and `EXIT_FAILURE', respectively.
        (main): Use `EXIT_SUCCESS' or `EXIT_FAILURE' for return value.
 
        * etags.c: Likewise.
diff --git a/lisp/ChangeLog.10 b/lisp/ChangeLog.10
index de73fe7f0a..7c080ea496 100644
--- a/lisp/ChangeLog.10
+++ b/lisp/ChangeLog.10
@@ -4788,7 +4788,7 @@
 2003-03-10  Thien-Thi Nguyen  <ttn@gnu.org>
 
        * progmodes/scheme.el (scheme-mode-syntax-table):
-       Construct w/o using `with-syntax-table'.
+       Construct without using `with-syntax-table'.
 
 2003-03-10  John Paul Wallington  <jpw@gnu.org>
 
diff --git a/lisp/ChangeLog.11 b/lisp/ChangeLog.11
index 53a83c638c..f16191e8b7 100644
--- a/lisp/ChangeLog.11
+++ b/lisp/ChangeLog.11
@@ -212,7 +212,7 @@
 2004-12-27  Richard M. Stallman  <rms@gnu.org>
 
        * files.el (buffer-save-without-query): New var (buffer-local).
-       (save-some-buffers): Save those buffers first, w/o asking.
+       (save-some-buffers): Save those buffers first, without asking.
 
        * files.el (insert-directory-ls-version): New variable.
        (insert-directory): When ls returns an error, test the version
@@ -491,7 +491,7 @@
        instead of `direction'.  Update callers.  When `del-count' is
        non-nil, delete that many characters, otherwise `count' characters
        backwards.  Insert the newly-replaced string `count' times.
-       (zone-fret): Handle chars w/ width greater than one.
+       (zone-fret): Handle chars with width greater than one.
        (zone-fall-through-ws): No longer take window width `ww'.
        Update callers.  Add handling for `char-width' greater than one.
        (zone-pgm-drip): Update var holding window-end position every cycle.
@@ -3584,7 +3584,8 @@
        * startup.el (fancy-splash-tail, normal-splash-screen):
        Update copyright year.
 
-       * shadowfile.el (shadowfile-unload-hook): Set as variable w/ add-hook.
+       * shadowfile.el (shadowfile-unload-hook): Set as variable with
+       add-hook.
 
        * server.el (server-unload-hook): Set as a variable with add-hook.
 
@@ -8939,7 +8940,7 @@
        (compilation-skip-visited, compilation-context-lines):
        Declare :version when added to Emacs.
        (compilation-error-regexp-alist-alist): Extend caml and irix.
-       (compilation-setup): Fix if font-locked w/o font-lock-defaults.
+       (compilation-setup): Fix if font-locked without font-lock-defaults.
        (compilation-mode-font-lock-keywords): Temporarily undo line as
        function patch, which wasn't ready.
 
diff --git a/lisp/ChangeLog.12 b/lisp/ChangeLog.12
index 0796965a9b..ec58ffc173 100644
--- a/lisp/ChangeLog.12
+++ b/lisp/ChangeLog.12
@@ -24499,8 +24499,9 @@
        is updated.
 
        * whitespace.el (whitespace-buffer-leading-cleanup):
-       Simplify w/ skip-chars-forward.
-       (whitespace-buffer-trailing-cleanup): Simplify w/ skip-chars-backward.
+       Simplify with skip-chars-forward.
+       (whitespace-buffer-trailing-cleanup): Simplify with
+       skip-chars-backward.
 
        * mail/rmail.el (rmail-only-expunge): Fix paren error.
        Unconditionally try to leave point at the same old place.
@@ -31346,7 +31347,7 @@
 
        * facemenu.el (list-colors-print): Print #RRGGBB in default face.
        Remove 1 space before #RRGGBB to not truncate it on terminal
-       windows w/o fringes.  Remove 1 space between bg and fg examples
+       windows without fringes.  Remove 1 space between bg and fg examples
        to get more space.
        (list-colors-duplicates): Replace `and' with `if' for `boundp' to
        avoid byte-compile warnings.
diff --git a/lisp/ChangeLog.14 b/lisp/ChangeLog.14
index 8d8c611778..eae47fe198 100644
--- a/lisp/ChangeLog.14
+++ b/lisp/ChangeLog.14
@@ -20218,7 +20218,7 @@
 2008-02-12  Stefan Monnier  <monnier@iro.umontreal.ca>
 
        * doc-view.el (doc-view-display): Change file arg to buffer arg, so it
-       works also for buffers w/o buffer-file-name.  Update callers.
+       works also for buffers without buffer-file-name.  Update callers.
        (doc-view-clone-buffer-hook): New fun.
        (doc-view-mode): Use it for indirect clones.  Mark the overlays with
        the `doc-view' property so they can be recognized.
diff --git a/lisp/ChangeLog.16 b/lisp/ChangeLog.16
index 7b57c014d2..1d7684be81 100644
--- a/lisp/ChangeLog.16
+++ b/lisp/ChangeLog.16
@@ -4871,7 +4871,8 @@
 
 2012-10-11  Stefan Monnier  <monnier@iro.umontreal.ca>
 
-       * help-fns.el (describe-function-1): Handle autoloads w/o docstrings.
+       * help-fns.el (describe-function-1): Handle autoloads without
+       docstrings.
 
        * emacs-lisp/bytecomp.el (byte-compile-eval): Adjust to long-ago
        changes to the format of load-history.
diff --git a/lisp/ChangeLog.3 b/lisp/ChangeLog.3
index e23226b844..46089685a3 100644
--- a/lisp/ChangeLog.3
+++ b/lisp/ChangeLog.3
@@ -4172,7 +4172,8 @@
        (next-matching-history-element): Likewise.
        (minibuffer-history-search-history): New variable.
 
-       * simple.el (read-expression-map): New keymap, w/ lisp-complete-symbol.
+       * simple.el (read-expression-map): New keymap, with
+       lisp-complete-symbol.
        (eval-expression, edit-and-eval-command): Use read-expression-map.
        (repeat-complex-command): Likewise.
 
diff --git a/lisp/ChangeLog.4 b/lisp/ChangeLog.4
index ea0502975e..ddea2a4e2f 100644
--- a/lisp/ChangeLog.4
+++ b/lisp/ChangeLog.4
@@ -7238,7 +7238,8 @@
        * ispell.el (ispell-menu-map): Add missing quote in defalias.
        (ispell-window-configuration): Initialize to nil.
 
-       * vc-hooks.el (vc-rcs-status): Make work buffer's name start w/ space.
+       * vc-hooks.el (vc-rcs-status): Make work buffer's name start with
+       space.
 
        * simple.el (completion-setup-function): Insert the mouse help message
        only if non-nil `window-system'.
diff --git a/lisp/ChangeLog.6 b/lisp/ChangeLog.6
index 27d522aaf2..8e07e5c36a 100644
--- a/lisp/ChangeLog.6
+++ b/lisp/ChangeLog.6
@@ -1915,7 +1915,7 @@
        * menu-bar.el (menu-bar-tools-menu): Delete ediff-doc and
        eregistry items.
 
-       * help.el (describe-mode): Handle minor mode w/o mode line indicator.
+       * help.el (describe-mode): Handle minor mode without mode line 
indicator.
 
        * bibtex.el (bibtex-version): Variable deleted.
        (bibtex-submit-bug-report): Don't use that.
diff --git a/lisp/ChangeLog.7 b/lisp/ChangeLog.7
index 3220832454..91b8d47422 100644
--- a/lisp/ChangeLog.7
+++ b/lisp/ChangeLog.7
@@ -1175,7 +1175,7 @@
        (speedbar-supported-extension-expressions): Add more extensions.
        (speedbar-add-supported-extension)
        (speedbar-add-ignored-path-regexp): Made interactive.
-       (speedbar-update-flag): Nil w/ no window system.
+       (speedbar-update-flag): Nil with no window system.
        (speedbar-file-key-map): Move some key bindings from
        `speedbar-key-map' to this map.
        (speedbar-make-specialized-keymap): New function.
@@ -4223,7 +4223,8 @@
        Do the right thing when nil is specified as criterion for activeness.
        Fix string used to report an invalid item.
 
-       * tmm.el (tmm-get-keymap): Handle new format menu item w/o cache.
+       * tmm.el (tmm-get-keymap): Handle new format menu item without
+       cache.
        (tmm-prompt): If reach an empty menu, get an error.
 
 1998-04-20  Per Starbäck  <starback@update.uu.se>
diff --git a/lisp/ChangeLog.8 b/lisp/ChangeLog.8
index a14d682192..3b6205bc60 100644
--- a/lisp/ChangeLog.8
+++ b/lisp/ChangeLog.8
@@ -117,7 +117,7 @@
        overlays if they interfere.
        (compilation-find-file): Make intangible overlays tangible.
 
-       * progmodes/hideshow.el: Generally, synch w/ maintainer
+       * progmodes/hideshow.el: Generally, synch with maintainer
        version 5.9.
 
        (hs-show-hidden-short-form): Delete var; hard-code uses as `t'.
@@ -6715,7 +6715,7 @@
 
        * speedbar.el (speedbar-item-info-file-helper): Add optional arg
        of the file whose info we want to display.
-       (speedbar-easymenu-definition-trailer) Fix list issue w/ customize.
+       (speedbar-easymenu-definition-trailer) Fix list issue with customize.
        (speedbar-add-mode-functions-list) Improve doc.
        (speedbar-line-token) New function.
        (speedbar-dired) Fix order of directories in -shown-directories.
@@ -9800,8 +9800,8 @@
 1998-08-27  Richard Stallman  <rms@gnu.org>
 
        * calendar/cal-tex.el (cal-tex-cursor-filofax-daily): Don't use oddp.
-       * calendar/appt.el (appt-check): Start the appt-mode-string w/ space.
-       Clear appt-mode-string if we don't put something in it.
+       * calendar/appt.el (appt-check): Start the appt-mode-string with
+       space.  Clear appt-mode-string if we don't put something in it.
 
 1998-08-27  Dave Love  <fx@gnu.org>
 
@@ -9979,7 +9979,8 @@
        (speedbar-mode): Set buffer to read only.
        (speedbar-temp-buffer-show-function): For Emacs don't call hook
        with arguments.
-       (speedbar-stealthy-updates): Do all updates w/ the buffer writable.
+       (speedbar-stealthy-updates): Do all updates with the buffer
+       writable.
 
 1998-08-19  Dan Nicolaescu  <done@ece.arizona.edu>
 
diff --git a/lisp/ChangeLog.9 b/lisp/ChangeLog.9
index 469d0970f8..be6ba962cf 100644
--- a/lisp/ChangeLog.9
+++ b/lisp/ChangeLog.9
@@ -1418,13 +1418,13 @@
 2001-08-28  Thien-Thi Nguyen  <ttn@gnu.org>
 
        * progmodes/hideshow.el: Update first-line description.
-       Sync comments w/ maintainer version 5.31.
+       Sync comments with maintainer version 5.31.
 
        (hs-isearch-open): Default value now `code'.
        Fix docstring to use "code blocks" vs "comment blocks",
        as opposed to "block" vs "comment".
        (hs-flag-region): Accept `hs-isearch-open' value
-       of `block' as synonymous w/ `code'.
+       of `block' as synonymous with `code'.
        (hs-hide-block-at-point): For code blocks, pass `code'
        to `hs-flag-region' instead of `block'.
 
@@ -11483,7 +11483,7 @@
 2000-09-23  Thien-Thi Nguyen  <ttn@gnu.org>
 
        * progmodes/hideshow.el: Update author email address.
-       Generally, sync w/ maintainer version 5.22.
+       Generally, sync with maintainer version 5.22.
        (hs-hide-all-non-comment-function): New var.
        (hs-hide-hook, hs-show-hook, hs-minor-mode): Update docstrings.
        (hs-hide-all): Use `hs-hide-all-non-comment-function'.
@@ -17879,7 +17879,7 @@
        (speedbar-make-button): Call `speedbar-insert-image-button-maybe'.
        (speedbar-directory-buttons): Update path search/expansion.
        (speedbar-make-tag-line): Pay attention to
-       `speedbar-indentation-width'.  Use more care w/ invisible
+       `speedbar-indentation-width'.  Use more care with invisible
        properties.
        (speedbar-change-expand-button-char):
        Call `speedbar-insert-image-button-maybe'.
diff --git a/lisp/autorevert.el b/lisp/autorevert.el
index e3d66c04bc..1ed3f693ab 100644
--- a/lisp/autorevert.el
+++ b/lisp/autorevert.el
@@ -718,7 +718,7 @@ system.")
                           (string-equal
                            (file-name-nondirectory file)
                            (file-name-nondirectory buffer-file-name)))
-                     ;; A buffer w/o a file, like dired.
+                     ;; A buffer without a file, like dired.
                      (null buffer-file-name))
                 (auto-revert-notify-rm-watch)
                 ;; Restart the timer if it wasn't running.
@@ -739,7 +739,7 @@ system.")
                               (string-equal
                                (file-name-nondirectory file1)
                                (file-name-nondirectory buffer-file-name)))))
-                   ;; A buffer w/o a file, like dired.
+                   ;; A buffer without a file, like dired.
                    (and (null buffer-file-name)
                         (memq action '(created renamed deleted))))
               ;; Mark buffer modified.
diff --git a/lisp/comint.el b/lisp/comint.el
index 93b97cb22b..4d9fc50187 100644
--- a/lisp/comint.el
+++ b/lisp/comint.el
@@ -78,7 +78,7 @@
 ;;
 ;; Not bound by default in comint-mode (some are in shell mode)
 ;; comint-run                          Run a program under comint-mode
-;; comint-send-invisible               Read a line w/o echo, and send to proc
+;; comint-send-invisible               Read a line without echo, and send to 
proc
 ;; comint-dynamic-complete-filename    Complete filename at point.
 ;; comint-dynamic-list-filename-completions List completions in help buffer.
 ;; comint-replace-by-expanded-filename Expand and complete filename at point;
diff --git a/lisp/emacs-lisp/chart.el b/lisp/emacs-lisp/chart.el
index 9ff893b75b..16c2c34740 100644
--- a/lisp/emacs-lisp/chart.el
+++ b/lisp/emacs-lisp/chart.el
@@ -35,7 +35,7 @@
 ;; anything encapsulated in a nice eieio object.
 ;;
 ;;   Current example apps for chart can be accessed via these commands:
-;; `chart-file-count'     - count files w/ matching extensions
+;; `chart-file-count'     - count files with matching extensions
 ;; `chart-space-usage'    - display space used by files/directories
 ;; `chart-emacs-storage'  - Emacs storage units used/free (garbage-collect)
 ;; `chart-emacs-lists'    - length of Emacs lists
diff --git a/lisp/emacs-lisp/package.el b/lisp/emacs-lisp/package.el
index f10dc91572..a9fd8c741e 100644
--- a/lisp/emacs-lisp/package.el
+++ b/lisp/emacs-lisp/package.el
@@ -3110,7 +3110,7 @@ package PKG-DESC, add one.  The alist is keyed with 
PKG-DESC."
   "If non-nil, include packages that don't have a version in `list-packages'.")
 
 (defvar package-list-unsigned nil
-  "If non-nil, mention in the list which packages were installed w/o 
signature.")
+  "If non-nil, mention in the list which packages were installed without 
signature.")
 
 (defvar package--emacs-version-list (version-to-list emacs-version)
   "The value of variable `emacs-version' as a list.")
diff --git a/lisp/epg.el b/lisp/epg.el
index ceeb269b07..527ebfcc2b 100644
--- a/lisp/epg.el
+++ b/lisp/epg.el
@@ -482,7 +482,7 @@ callback data (if any)."
              (format "      skipped new keys: %d\n"
                      (epg-import-result-not-imported import-result)))
          (if (> (epg-import-result-no-user-id import-result) 0)
-             (format "          w/o user IDs: %d\n"
+             (format "          without user IDs: %d\n"
                      (epg-import-result-no-user-id import-result)))
          (if (> (epg-import-result-imported import-result) 0)
              (concat (format "              imported: %d"
diff --git a/lisp/gnus/ChangeLog.3 b/lisp/gnus/ChangeLog.3
index c55d6225e3..3b41e9edc9 100644
--- a/lisp/gnus/ChangeLog.3
+++ b/lisp/gnus/ChangeLog.3
@@ -22675,7 +22675,8 @@
        * nnspool.el (nnspool-spool-directory): Use news-directory instead
        of news-path.
 
-       * spam-stat.el (spam-stat-unload-hook): Set as a variable w/ add-hook.
+       * spam-stat.el (spam-stat-unload-hook): Set as a variable with
+       add-hook.
 
        * spam.el: Delete duplicate `provide'.
        (spam-unload-hook): Set as a variable with add-hook.
diff --git a/lisp/gnus/gnus-cache.el b/lisp/gnus/gnus-cache.el
index 449b73163f..13c9c0130e 100644
--- a/lisp/gnus/gnus-cache.el
+++ b/lisp/gnus/gnus-cache.el
@@ -137,7 +137,7 @@ it's not cached."
              ;; If possible, remove group's cache subdirectory.
              (condition-case nil
                  ;; FIXME: we can detect the error type and warn the user
-                 ;; of any inconsistencies (articles w/o nov entries?).
+                 ;; of any inconsistencies (articles without nov entries?).
                  ;; for now, just be conservative...delete only if safe -- sj
                  (delete-directory (file-name-directory overview-file))
                (error))))
diff --git a/lisp/gnus/message.el b/lisp/gnus/message.el
index 5589908764..e7d11b597b 100644
--- a/lisp/gnus/message.el
+++ b/lisp/gnus/message.el
@@ -2909,7 +2909,7 @@ Consider adding this function to 
`message-header-setup-hook'"
   "C-c C-f s"    #'message-change-subject
   ;;
   "C-c C-f x"    #'message-cross-post-followup-to
-  ;; prefix+message-cross-post-followup-to = same w/o cross-post
+  ;; prefix+message-cross-post-followup-to = same without cross-post
   "C-c C-f t"    #'message-reduce-to-to-cc
   "C-c C-f a"    #'message-add-archive-header
   ;; mark inserted text
diff --git a/lisp/net/ange-ftp.el b/lisp/net/ange-ftp.el
index d6d0fb9a25..6e17e417ea 100644
--- a/lisp/net/ange-ftp.el
+++ b/lisp/net/ange-ftp.el
@@ -218,7 +218,7 @@
 ;; ange-ftp-smart-gateway and ange-ftp-smart-gateway-port.
 ;;
 ;; Otherwise, if there is an alternate ftp program that implements proxy in
-;; a transparent way (i.e. w/o specifying the proxy host), that will
+;; a transparent way (i.e. without specifying the proxy host), that will
 ;; connect you directly to the desired destination host:
 ;; Set ange-ftp-gateway-ftp-program-name to that program's name.
 ;; Set ange-ftp-local-host-regexp to a value as stated earlier on.
diff --git a/lisp/obsolete/rfc2368.el b/lisp/obsolete/rfc2368.el
index 5e7320a793..0a75296e7d 100644
--- a/lisp/obsolete/rfc2368.el
+++ b/lisp/obsolete/rfc2368.el
@@ -27,7 +27,7 @@
 ;;
 ;;   -repeat after me: "the colon is not part of the header name..."
 ;;   -if w3 becomes part of emacs, then it may make sense to have this
-;;    file depend on w3 -- the maintainer of w3 says merging w/ Emacs
+;;    file depend on w3 -- the maintainer of w3 says merging with Emacs
 ;;    is planned!
 ;;
 ;; historical note:
@@ -36,8 +36,8 @@
 ;;
 ;; acknowledgments:
 ;;
-;;   the functions that deal w/ unhexifying in this file were basically
-;; taken from w3 -- i hope to replace them w/ something else soon OR
+;;   the functions that deal with unhexifying in this file were basically
+;; taken from w3 -- i hope to replace them with something else soon OR
 ;; perhaps if w3 becomes a part of emacs soon, use the functions from w3.
 
 ;;; History:
@@ -85,9 +85,9 @@
 
 (defun rfc2368-parse-mailto-url (mailto-url)
   "Parse MAILTO-URL, and return an alist of header-name, header-value pairs.
-MAILTO-URL should be a RFC 2368 (mailto) compliant url.  A cons cell w/ a
+MAILTO-URL should be a RFC 2368 (mailto) compliant url.  A cons cell with a
 key of `Body' is a special case and is considered a header for this purpose.
-The returned alist is intended for use w/ the `compose-mail' interface.
+The returned alist is intended for use with the `compose-mail' interface.
 Note: make sure MAILTO-URL has been \"unhtmlized\" (e.g., &amp; -> &), before
 calling this function."
   (let ((case-fold-search t)
@@ -114,7 +114,7 @@ calling this function."
                          (rfc2368-unhexify-string header-value))))
                     (split-string query "&"))))
 
-         ;; deal w/ multiple 'To' recipients
+         ;; deal with multiple 'To' recipients
          (if prequery
              (progn
                (setq prequery (rfc2368-unhexify-string prequery))
diff --git a/lisp/org/ChangeLog.1 b/lisp/org/ChangeLog.1
index 1491a4645a..f79d8bf674 100644
--- a/lisp/org/ChangeLog.1
+++ b/lisp/org/ChangeLog.1
@@ -23889,7 +23889,7 @@
 2010-11-11  Eric Schulte  <schulte.eric@gmail.com>
 
        * ob-sqlite.el (org-babel-sqlite-expand-vars): Now inserts string
-       arguments w/o quotes.
+       arguments without quotes.
 
 2010-11-11  Bernt Hansen  <bernt@norang.ca>
 
@@ -23909,7 +23909,7 @@
 2010-11-11  Eric Schulte  <schulte.eric@gmail.com>
 
        * ob-lob.el (org-babel-lob-one-liner-regexp): Fix error in lob
-       regexp -- it wasn't matching lob lines w/o indices.
+       regexp -- it wasn't matching lob lines without indices.
 
 2010-11-11  Eric Schulte  <schulte.eric@gmail.com>
 
diff --git a/lisp/play/zone.el b/lisp/play/zone.el
index a470f23dfe..6e27ba5165 100644
--- a/lisp/play/zone.el
+++ b/lisp/play/zone.el
@@ -320,7 +320,7 @@ run a specific program.  The program must be a member of
   (zone-pgm-jitter))
 
 
-;;;; putzing w/ case
+;;;; putzing with case
 
 ;; Faster than `zone-pgm-putz-with-case', but not as good: all
 ;; instances of the same letter have the same case, which produces a
diff --git a/lisp/progmodes/antlr-mode.el b/lisp/progmodes/antlr-mode.el
index b722790334..efee400681 100644
--- a/lisp/progmodes/antlr-mode.el
+++ b/lisp/progmodes/antlr-mode.el
@@ -1777,7 +1777,7 @@ For AREA and OLD, see `antlr-insert-option-do'."
        (skip-chars-forward " \t")
 
        (if (looking-at "$\\|//")
-           ;; just comment after point => skip (+ lines w/ same col comment)
+            ;; just comment after point => skip (+ lines with same col comment)
            (let ((same (if (> (match-end 0) (match-beginning 0))
                            (current-column))))
              (beginning-of-line 2)
diff --git a/lisp/progmodes/asm-mode.el b/lisp/progmodes/asm-mode.el
index aaf063b517..2a63c10002 100644
--- a/lisp/progmodes/asm-mode.el
+++ b/lisp/progmodes/asm-mode.el
@@ -209,7 +209,7 @@ repeatedly until you are satisfied with the kind of 
comment."
     (indent-according-to-mode)
     (insert asm-comment-char asm-comment-char ?\ ))
 
-   ;; Nonblank line w/o comment => start a comment at comment-column.
+   ;; Nonblank line without comment => start a comment at comment-column.
    ;; Also: point before the comment => jump inside.
    ((or (null comment) (< (point) comment))
     (indent-for-comment))
diff --git a/lisp/progmodes/compile.el b/lisp/progmodes/compile.el
index 18c996e899..e8ada9388e 100644
--- a/lisp/progmodes/compile.el
+++ b/lisp/progmodes/compile.el
@@ -2807,7 +2807,7 @@ This is the value of `next-error-function' in Compilation 
buffers."
             (goto-char (point-min))
             ;; Treat file's found lines in forward order, 1 by 1.
             (dolist (line (reverse (cddr (compilation--loc->file-struct loc))))
-              (when (car line)         ; else this is a filename w/o a line#
+              (when (car line)         ; else this is a filename without a 
line#
                 (compilation-beginning-of-line (- (car line) last -1))
                 (setq last (car line)))
               ;; Treat line's found columns and store/update a marker for each.
diff --git a/lisp/progmodes/scheme.el b/lisp/progmodes/scheme.el
index e0453c3b2f..8454f24356 100644
--- a/lisp/progmodes/scheme.el
+++ b/lisp/progmodes/scheme.el
@@ -361,7 +361,7 @@ See `run-hooks'."
               ) t)
         "\\>") 1)
       ;;
-      ;; It wouldn't be Scheme w/o named-let.
+      ;; It wouldn't be Scheme without named-let.
       '("(let\\s-+\\(\\sw+\\)"
         (1 font-lock-function-name-face))
       ;;
diff --git a/lisp/shell.el b/lisp/shell.el
index 7c3c925ab8..b396bc2b18 100644
--- a/lisp/shell.el
+++ b/lisp/shell.el
@@ -71,7 +71,7 @@
 ;; c-c c-o comint-delete-output                   Delete last batch of process 
output
 ;; c-c c-r comint-show-output             Show last batch of process output
 ;; c-c c-l comint-dynamic-list-input-ring  List input history
-;;         comint-send-invisible           Read line w/o echo & send to proc
+;;         comint-send-invisible           Read line without echo & send to 
proc
 ;;         comint-continue-subjob         Useful if you accidentally suspend
 ;;                                             top-level job
 ;; comint-mode-hook is the comint mode hook.
diff --git a/lisp/strokes.el b/lisp/strokes.el
index 0f84588a41..e5719dfd5d 100644
--- a/lisp/strokes.el
+++ b/lisp/strokes.el
@@ -1151,7 +1151,7 @@ the stroke as a character in some language."
                                                     strokes-last-stroke)
                                                 31))))
          (lift-flag t)
-         (rainbow-chars (list ?R ?O ?Y ?G ?B ?P))) ; ROYGBIV w/o indigo
+         (rainbow-chars (list ?R ?O ?Y ?G ?B ?P))) ; ROYGBIV without indigo
       (set-buffer buf)
       (erase-buffer)
       (insert strokes-xpm-header)
diff --git a/lisp/term.el b/lisp/term.el
index 755c220270..6f3306b088 100644
--- a/lisp/term.el
+++ b/lisp/term.el
@@ -278,7 +278,7 @@
 ;; C-c C-h term-dynamic-list-input-ring  List input history
 ;;
 ;; Not bound by default in term-mode
-;; term-send-invisible                 Read a line w/o echo, and send to proc
+;; term-send-invisible                 Read a line without echo, and send to 
proc
 ;; (These are bound in shell-mode)
 ;; term-dynamic-complete               Complete filename at point.
 ;; term-dynamic-list-completions       List completions in help buffer.
diff --git a/lisp/textmodes/reftex.el b/lisp/textmodes/reftex.el
index e72576cdc7..f815419ea4 100644
--- a/lisp/textmodes/reftex.el
+++ b/lisp/textmodes/reftex.el
@@ -2053,7 +2053,8 @@ IGNORE-WORDS List of words which should be removed from 
the string."
          (newname (concat "Fontify-me-" oldname)))
     (unwind-protect
         (progn
-          ;; Rename buffer temporarily to start w/o space (because of 
font-lock)
+          ;; Rename buffer temporarily to start without space (because
+          ;; of font-lock)
           (rename-buffer newname t)
           ;; Good: we have the indirection functions
           (set (make-local-variable 'font-lock-fontify-region-function)
diff --git a/lisp/vc/vc-rcs.el b/lisp/vc/vc-rcs.el
index c41835e19f..bf1d847f1a 100644
--- a/lisp/vc/vc-rcs.el
+++ b/lisp/vc/vc-rcs.el
@@ -683,11 +683,11 @@ Optional arg REVISION is a revision to annotate from."
         ;; *BEFORE* editing occurs) to start from, but line numbers
         ;; change as a result of edits.  To DTRT, we apply edits in
         ;; order of descending buffer position so that edits further
-        ;; down in the buffer occur first w/o corrupting specified
+        ;; down in the buffer occur first without corrupting specified
         ;; buffer positions of edits occurring towards the beginning of
         ;; the buffer.  In this way we avoid using markers.  A pleasant
         ;; property of this approach is ability to push instructions
-        ;; onto `path' directly, w/o need to maintain rev boundaries.
+        ;; onto `path' directly, without need to maintain rev boundaries.
         (dolist (insn (cdr (assq :insn meta)))
           (goto-char (point-min))
           (forward-line (1- (pop insn)))
diff --git a/src/ChangeLog.11 b/src/ChangeLog.11
index a00ca453ca..77180262ac 100644
--- a/src/ChangeLog.11
+++ b/src/ChangeLog.11
@@ -14235,7 +14235,7 @@
        ns_alternate_modifier.  (Bug#1217)
 
        * nsmenu.m (EmacsMenu-parseKeyEquiv:, addItemWithWidgetValue:):
-       Display all shortcuts, including those w/o super modifier.
+       Display all shortcuts, including those without super modifier.
 
        * nsfns.m (ns-read-file-name): Fix typo in assignment statement.
 
diff --git a/src/ChangeLog.3 b/src/ChangeLog.3
index 4b3675eaa8..d32e894fa5 100644
--- a/src/ChangeLog.3
+++ b/src/ChangeLog.3
@@ -14422,7 +14422,7 @@
        * s-umips.h: Now include either s-usg5-2-2.h or s-bsd4-3.h
        and then override as needed.
        * m-mips.h: System dependence deleted.
-       LD_SWITCH_MACHINE remains w/ options needed on all systems.
+       LD_SWITCH_MACHINE remains with options needed on all systems.
        * m-pmax.h: A little of that (LIBS_DEBUG) moved here.
        No need to undef LIBS_MACHINE.
 
diff --git a/src/xdisp.c b/src/xdisp.c
index b09aa6ec96..171c6ccaa0 100644
--- a/src/xdisp.c
+++ b/src/xdisp.c
@@ -22616,7 +22616,8 @@ usage: (trace-to-stderr STRING &rest OBJECTS)  */)
  ***********************************************************************/
 
 /* Return a temporary glyph row holding the glyphs of an overlay arrow.
-   Used for non-window-redisplay windows, and for windows w/o left fringe.  */
+   Used for non-window-redisplay windows, and for windows without left
+   fringe.  */
 
 static struct glyph_row *
 get_overlay_arrow_glyph_row (struct window *w, Lisp_Object 
overlay_arrow_string)
diff --git a/test/lisp/cedet/semantic-utest.el 
b/test/lisp/cedet/semantic-utest.el
index b577b19808..4aaa4c5e3c 100644
--- a/test/lisp/cedet/semantic-utest.el
+++ b/test/lisp/cedet/semantic-utest.el
@@ -593,7 +593,7 @@ INSERTME is the text to be inserted after the deletion."
   )
 
 (ert-deftest semantic-utest-Scheme()
-  (skip-unless nil) ;; There is a bug w/ scheme parser.  Skip this for now.
+  (skip-unless nil) ;; There is a bug with scheme parser.  Skip this for now.
   (semantic-utest-generic (semantic-utest-fname "tst.scm") 
semantic-utest-Scheme-buffer-contents  semantic-utest-Scheme-name-contents   
'("fun2") ";1" ";deleted line")
   )
 
diff --git a/test/lisp/emacs-lisp/eieio-tests/eieio-test-methodinvoke.el 
b/test/lisp/emacs-lisp/eieio-tests/eieio-test-methodinvoke.el
index af19c122b9..05d24a8e35 100644
--- a/test/lisp/emacs-lisp/eieio-tests/eieio-test-methodinvoke.el
+++ b/test/lisp/emacs-lisp/eieio-tests/eieio-test-methodinvoke.el
@@ -308,7 +308,7 @@
     (setq eieio-test-method-order-list (nreverse eieio-test-method-order-list))
     (eieio-test-match ans)))
 
-;;; Jan's methodinvoke order w/ multiple inheritance and :after methods.
+;;; Jan's methodinvoke order with multiple inheritance and :after methods.
 ;;
 (defclass eitest-Ja ()
   ())
diff --git a/test/lisp/erc/erc-join-tests.el b/test/lisp/erc/erc-join-tests.el
index 8210defbfb..89521ba429 100644
--- a/test/lisp/erc/erc-join-tests.el
+++ b/test/lisp/erc/erc-join-tests.el
@@ -335,7 +335,7 @@
               (start-process "true" (current-buffer) "true")
               erc-server-current-nick "tester"
               erc-server-announced-name "foo.gnu.chat"
-              ;; Assume special case w/o known network
+              ;; Assume special case without known network
               erc-networks--id (make-erc-networks--id))
         (set-process-query-on-exit-flag erc-server-process nil)
         (should-not calls)
diff --git a/test/lisp/filenotify-tests.el b/test/lisp/filenotify-tests.el
index d82e2dae7a..724cd63e22 100644
--- a/test/lisp/filenotify-tests.el
+++ b/test/lisp/filenotify-tests.el
@@ -1590,8 +1590,8 @@ the file watch."
   (unwind-protect
       (progn
        (write-region "any text" nil file-notify--test-tmpfile1 nil 'no-message)
-        ;; Some systems, like MS Windows w/o sufficient privileges, do
-        ;; not allow creation of symbolic links.
+        ;; Some systems, like MS Windows without sufficient
+        ;; privileges, do not allow creation of symbolic links.
         (condition-case nil
             (make-symbolic-link
              file-notify--test-tmpfile1 file-notify--test-tmpfile)
diff --git a/test/lisp/net/tramp-archive-tests.el 
b/test/lisp/net/tramp-archive-tests.el
index f8a0aa03e3..d9eafc47ad 100644
--- a/test/lisp/net/tramp-archive-tests.el
+++ b/test/lisp/net/tramp-archive-tests.el
@@ -123,7 +123,7 @@ the origin of the temporary TMPFILE, have no write 
permissions."
 
 (defun tramp-archive--test-emacs27-p ()
   "Check for Emacs version >= 27.1.
-Some semantics has been changed for there, w/o new functions or
+Some semantics has been changed for there, without new functions or
 variables, so we check the Emacs version directly."
   (>= emacs-major-version 27))
 
diff --git a/test/lisp/net/tramp-tests.el b/test/lisp/net/tramp-tests.el
index 6ffb8a6529..79b2fc803d 100644
--- a/test/lisp/net/tramp-tests.el
+++ b/test/lisp/net/tramp-tests.el
@@ -6597,20 +6597,20 @@ INPUT, if non-nil, is a string sent to the process."
 
 (defun tramp--test-emacs27-p ()
   "Check for Emacs version >= 27.1.
-Some semantics has been changed for there, w/o new functions or
-variables, so we check the Emacs version directly."
+Some semantics has been changed for there, without new functions
+or variables, so we check the Emacs version directly."
   (>= emacs-major-version 27))
 
 (defun tramp--test-emacs28-p ()
   "Check for Emacs version >= 28.1.
-Some semantics has been changed for there, w/o new functions or
-variables, so we check the Emacs version directly."
+Some semantics has been changed for there, without new functions
+or variables, so we check the Emacs version directly."
   (>= emacs-major-version 28))
 
 (defun tramp--test-emacs29-p ()
   "Check for Emacs version >= 29.1.
-Some semantics has been changed for there, w/o new functions or
-variables, so we check the Emacs version directly."
+Some semantics has been changed for there, without new functions
+or variables, so we check the Emacs version directly."
   (>= emacs-major-version 29))
 
 (defun tramp--test-adb-p ()
diff --git a/test/manual/cedet/cedet-utests.el 
b/test/manual/cedet/cedet-utests.el
index b365908c63..2c5ba46855 100644
--- a/test/manual/cedet/cedet-utests.el
+++ b/test/manual/cedet/cedet-utests.el
@@ -333,7 +333,8 @@ ERRORCONDITION is some error that may have occurred during 
testing."
   "Add into the log that the last item is done.
 Apply NOTES to the doneness of the log.
 Apply ERR if there was an error in previous item.
-Optional argument PRECR indicates to prefix the done msg w/ a newline."
+Optional argument PRECR indicates to prefix the done message with
+a newline."
   (if noninteractive
       ;; Non-interactive-mode - show a message.
       (if notes
diff --git a/test/manual/cedet/semantic-tests.el 
b/test/manual/cedet/semantic-tests.el
index dcdeb45b0a..1d0e668d96 100644
--- a/test/manual/cedet/semantic-tests.el
+++ b/test/manual/cedet/semantic-tests.el
@@ -87,7 +87,8 @@ run the test again")))
 (defun semanticdb-test-gnu-global (searchfor &optional standardfile)
   "Test the GNU Global semanticdb.
 Argument SEARCHFOR is the text to search for.
-If optional arg STANDARDFILE is non-nil, use a standard file w/ global 
enabled."
+If optional arg STANDARDFILE is non-nil, use a standard file with
+global enabled."
   (interactive "sSearch For Tag: \nP")
 
   (require 'data-debug)
diff --git a/test/manual/cedet/tests/testpolymorph.cpp 
b/test/manual/cedet/tests/testpolymorph.cpp
index ba64e39a7a..cfe44ecc4d 100644
--- a/test/manual/cedet/tests/testpolymorph.cpp
+++ b/test/manual/cedet/tests/testpolymorph.cpp
@@ -22,7 +22,7 @@
 
 #include <cmath>
 
-// Test 1 - Functions w/ prototypes
+// Test 1 - Functions with prototypes
 namespace proto {
 
   int pt_func1(int arg1);
@@ -32,7 +32,7 @@ namespace proto {
 
 }
 
-// Test 2 - Functions w/ different arg lists.
+// Test 2 - Functions with different arg lists.
 namespace fcn_poly {
 
   int pm_func(void) {
@@ -50,7 +50,7 @@ namespace fcn_poly {
 
 }
 
-// Test 3 - Methods w/ different arg lists.
+// Test 3 - Methods with different arg lists.
 class meth_poly {
 public:
   int pm_meth(void) {
@@ -68,7 +68,7 @@ public:
 
 };
 
-// Test 4 - Templates w/ partial specifiers.
+// Test 4 - Templates with partial specifiers.
 namespace template_partial_spec {
   template <typename T> class test
   {
@@ -83,7 +83,7 @@ namespace template_partial_spec {
   };
 }
 
-// Test 5 - Templates w/ full specialization which may or may not share
+// Test 5 - Templates with full specialization which may or may not share
 // common functions.
 namespace template_full_spec {
   template <typename T> class test
diff --git a/test/manual/cedet/tests/testsppreplace.c 
b/test/manual/cedet/tests/testsppreplace.c
index 54ae3f0323..d255c202d3 100644
--- a/test/manual/cedet/tests/testsppreplace.c
+++ b/test/manual/cedet/tests/testsppreplace.c
@@ -66,7 +66,7 @@ int myFcn3 (int a, int b);
 
 MULTI_ARGS(ma_struct, moose, penguin, emu);
 
-/* TEST: Macro w/ args, but no body. */
+/* TEST: Macro with args, but no body. */
 #define NO_BODY(name)
 
 NO_BODY(Moose);
@@ -78,7 +78,7 @@ int not_with_args_fcn NOT_WITH_ARGS
 {
 }
 
-/* TEST: macro w/ continuation. */
+/* TEST: macro with continuation. */
 #define WITH_CONT \
   continuation_symbol
 
diff --git a/test/manual/cedet/tests/testsppreplaced.c 
b/test/manual/cedet/tests/testsppreplaced.c
index c359fa7d69..c98349174e 100644
--- a/test/manual/cedet/tests/testsppreplaced.c
+++ b/test/manual/cedet/tests/testsppreplaced.c
@@ -55,14 +55,14 @@ int myFcn3 (int a, int b);
 /* TEST: Multiple args to a macro. */
 struct ma_struct { int moose; int penguin; int emu; };
 
-/* TEST: Macro w/ args, but no body. */
+/* TEST: Macro with args, but no body. */
 
 /* TEST: Not a macro with args, but close. */
 int not_with_args_fcn (moose)
 {
 }
 
-/* TEST: macro w/ continuation. */
+/* TEST: macro with continuation. */
 int continuation_symbol () { };
 
 /* TEST: macros in a macro - tail processing */



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/net/tramp.el b/lisp/net/tramp.el
index 33e5e80d05..9b7117cb87 100644
--- a/lisp/net/tramp.el
+++ b/lisp/net/tramp.el
@@ -2949,7 +2949,7 @@ They are completed by \"M-x TAB\" only if the current 
buffer is remote."
   (tramp-tramp-file-p (tramp-get-default-directory buffer)))
 
 (defun tramp-connectable-p (vec-or-filename)
-  "Check, whether it is possible to connect the remote host w/o side-effects.
+  "Check if it is possible to connect the remote host without side-effects.
 This is true, if either the remote host is already connected, or if we are
 not in completion mode."
   (let ((tramp-verbose 0)
@@ -3999,7 +3999,7 @@ Let-bind it when necessary.")
    ((not (file-exists-p file1)) nil)
    ((not (file-exists-p file2)) t)
    ;; Tramp reads and writes timestamps on second level.  So we round
    ;; the timestamps to seconds w/o fractions.
    ;; `time-convert' has been introduced with Emacs 27.1.
    ((fboundp 'time-convert)
     (time-less-p
@@ -3999,7 +3999,7 @@ Let-bind it when necessary.")
    ((not (file-exists-p file2)) t)
    ;; Tramp reads and writes timestamps on second level.  So we round
-   ;; the timestamps to seconds w/o fractions.
+   ;; the timestamps to seconds without fractions.
    ;; `time-convert' has been introduced with Emacs 27.1.
    ((fboundp 'time-convert)